pub struct DeviceGetClientTypeResponse {
pub client_type: String,
}Fields
client_type: StringTrait Implementations
Sourceimpl Clone for DeviceGetClientTypeResponse
impl Clone for DeviceGetClientTypeResponse
Sourcefn clone(&self) -> DeviceGetClientTypeResponse
fn clone(&self) -> DeviceGetClientTypeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetClientTypeResponse
impl Debug for DeviceGetClientTypeResponse
Sourceimpl<D> Decode<DeviceGetClientTypeResponse, D> for DeviceGetClientTypeResponsewhere
D: ResourceDialect,
impl<D> Decode<DeviceGetClientTypeResponse, D> for DeviceGetClientTypeResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> DeviceGetClientTypeResponse
fn new_empty() -> DeviceGetClientTypeResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<DeviceGetClientTypeResponse, D> for &DeviceGetClientTypeResponsewhere
D: ResourceDialect,
impl<D> Encode<DeviceGetClientTypeResponse, D> for &DeviceGetClientTypeResponsewhere
D: ResourceDialect,
impl Eq for DeviceGetClientTypeResponse
Sourceimpl Hash for DeviceGetClientTypeResponse
impl Hash for DeviceGetClientTypeResponse
Sourceimpl Ord for DeviceGetClientTypeResponse
impl Ord for DeviceGetClientTypeResponse
Sourcefn cmp(&self, other: &DeviceGetClientTypeResponse) -> Ordering
fn cmp(&self, other: &DeviceGetClientTypeResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetClientTypeResponse
impl PartialEq for DeviceGetClientTypeResponse
Sourcefn eq(&self, other: &DeviceGetClientTypeResponse) -> bool
fn eq(&self, other: &DeviceGetClientTypeResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetClientTypeResponse
impl PartialOrd for DeviceGetClientTypeResponse
impl Persistable for DeviceGetClientTypeResponse
impl StructuralPartialEq for DeviceGetClientTypeResponse
Sourceimpl TypeMarker for DeviceGetClientTypeResponse
impl TypeMarker for DeviceGetClientTypeResponse
Sourcetype Owned = DeviceGetClientTypeResponse
type Owned = DeviceGetClientTypeResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceGetClientTypeResponse
impl ValueTypeMarker for DeviceGetClientTypeResponse
Sourcetype Borrowed<'a> = &'a DeviceGetClientTypeResponse
type Borrowed<'a> = &'a DeviceGetClientTypeResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DeviceGetClientTypeResponse as TypeMarker>::Owned,
) -> <DeviceGetClientTypeResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DeviceGetClientTypeResponse as TypeMarker>::Owned, ) -> <DeviceGetClientTypeResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for DeviceGetClientTypeResponse
impl RefUnwindSafe for DeviceGetClientTypeResponse
impl Send for DeviceGetClientTypeResponse
impl Sync for DeviceGetClientTypeResponse
impl Unpin for DeviceGetClientTypeResponse
impl UnsafeUnpin for DeviceGetClientTypeResponse
impl UnwindSafe for DeviceGetClientTypeResponse