pub struct DeviceSynchronousProxy { /* private fields */ }Implementations
Sourceimpl DeviceSynchronousProxy
impl DeviceSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<DeviceEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DeviceEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn get_fan_level(
&self,
___deadline: MonotonicInstant,
) -> Result<(i32, u32), Error>
pub fn get_fan_level( &self, ___deadline: MonotonicInstant, ) -> Result<(i32, u32), Error>
Get the current fan level.
- response
statusZX_ERR_INTERNAL iffan_levelis not available. This generally means thatfan_levelhas not been initialized yet or something has gone terribly wrong. - response
fan_levela uint32 field indicating the current fan level. See fan level description above.
Sourcepub fn set_fan_level(
&self,
fan_level: u32,
___deadline: MonotonicInstant,
) -> Result<i32, Error>
pub fn set_fan_level( &self, fan_level: u32, ___deadline: MonotonicInstant, ) -> Result<i32, Error>
Set the fan level.
- request
fan_levela uint32 field indicating the requested fan level. See fan level description above.
- response
statusZX_ERR_OUT_OF_RANGE if the requested fan_level is not valid.
Sourcepub fn get_client_type(
&self,
___deadline: MonotonicInstant,
) -> Result<String, Error>
pub fn get_client_type( &self, ___deadline: MonotonicInstant, ) -> Result<String, Error>
Returns the client type to use for
fuchsia.thermal.ClientStateConnector::Connect.