pub struct FanMarker;Trait Implementations
impl Copy for FanMarker
impl Eq for FanMarker
Sourceimpl Ord for FanMarker
impl Ord for FanMarker
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for FanMarker
impl PartialOrd for FanMarker
Sourceimpl ProtocolMarker for FanMarker
impl ProtocolMarker for FanMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) Fan"
const DEBUG_NAME: &'static str = "(anonymous) Fan"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = FanProxy
type Proxy = FanProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = FanRequestStream
type RequestStream = FanRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = FanSynchronousProxy
type SynchronousProxy = FanSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for FanMarker