pub struct FanProxy { /* private fields */ }Implementations
Sourceimpl FanProxy
impl FanProxy
Sourcepub fn take_event_stream(&self) -> FanEventStream
pub fn take_event_stream(&self) -> FanEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_fan_level(
&self,
) -> QueryResponseFut<(i32, u32), DefaultFuchsiaResourceDialect>
pub fn get_fan_level( &self, ) -> QueryResponseFut<(i32, u32), DefaultFuchsiaResourceDialect>
Get the current fan level.
- response
statusZX_ERR_INTERNAL iffan_levelis not available. This generally means thatfan_levelhas not been initialized yet or something has gone terribly wrong. - response
fan_levela uint32 field indicating the current fan level. See fan level description above.
Sourcepub fn set_fan_level(
&self,
fan_level: u32,
) -> QueryResponseFut<i32, DefaultFuchsiaResourceDialect>
pub fn set_fan_level( &self, fan_level: u32, ) -> QueryResponseFut<i32, DefaultFuchsiaResourceDialect>
Set the fan level.
- request
fan_levela uint32 field indicating the requested fan level. See fan level description above.
- response
statusZX_ERR_OUT_OF_RANGE if the requested fan_level is not valid.